==> apo-ws-client-6.00.10.1-sources.jar: fr/univlorraine/apowsclient/creationSE/TypeHeureDTO.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour TypeHeureDTO complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="TypeHeureDTO"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codTypHeure" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="nbrHeureElp" type="{ElementPedagogiDTO6.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableDecimal" minOccurs="0"/&gt;
 *         &lt;element name="normeGroupe" type="{ElementPedagogiDTO6.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableInt" minOccurs="0"/&gt;
 *         &lt;element name="nbrMinEtuOuvertureGroupeSupp" type="{ElementPedagogiDTO6.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableInt" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TypeHeureDTO", propOrder = {
    "codTypHeure",
    "nbrHeureElp",
    "normeGroupe",
    "nbrMinEtuOuvertureGroupeSupp"
})
public class TypeHeureDTO {

    @XmlElement(required = true)
    protected String codTypHeure;
    @XmlElementRef(name = "nbrHeureElp", type = JAXBElement.class, required = false)
    protected JAXBElement<String> nbrHeureElp;
    @XmlElementRef(name = "normeGroupe", type = JAXBElement.class, required = false)
    protected JAXBElement<String> normeGroupe;
    @XmlElementRef(name = "nbrMinEtuOuvertureGroupeSupp", type = JAXBElement.class, required = false)
    protected JAXBElement<String> nbrMinEtuOuvertureGroupeSupp;

    /**
     * Obtient la valeur de la propriété codTypHeure.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodTypHeure() {
        return codTypHeure;
    }

    /**
     * Définit la valeur de la propriété codTypHeure.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodTypHeure(String value) {
        this.codTypHeure = value;
    }

    /**
     * Obtient la valeur de la propriété nbrHeureElp.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getNbrHeureElp() {
        return nbrHeureElp;
    }

    /**
     * Définit la valeur de la propriété nbrHeureElp.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setNbrHeureElp(JAXBElement<String> value) {
        this.nbrHeureElp = value;
    }

    /**
     * Obtient la valeur de la propriété normeGroupe.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getNormeGroupe() {
        return normeGroupe;
    }

    /**
     * Définit la valeur de la propriété normeGroupe.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setNormeGroupe(JAXBElement<String> value) {
        this.normeGroupe = value;
    }

    /**
     * Obtient la valeur de la propriété nbrMinEtuOuvertureGroupeSupp.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getNbrMinEtuOuvertureGroupeSupp() {
        return nbrMinEtuOuvertureGroupeSupp;
    }

    /**
     * Définit la valeur de la propriété nbrMinEtuOuvertureGroupeSupp.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setNbrMinEtuOuvertureGroupeSupp(JAXBElement<String> value) {
        this.nbrMinEtuOuvertureGroupeSupp = value;
    }

}

==> apo-ws-client-6.00.50.2-sources.jar: fr/univlorraine/apowsclient/creationSE/TypeHeureDTO.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour TypeHeureDTO complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="TypeHeureDTO"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codTypHeure" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="nbrHeureElp" type="{ElementPedagogiDTO6.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableDecimal" minOccurs="0"/&gt;
 *         &lt;element name="normeGroupe" type="{ElementPedagogiDTO6.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableInt" minOccurs="0"/&gt;
 *         &lt;element name="nbrMinEtuOuvertureGroupeSupp" type="{ElementPedagogiDTO6.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableInt" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TypeHeureDTO", propOrder = {
    "codTypHeure",
    "nbrHeureElp",
    "normeGroupe",
    "nbrMinEtuOuvertureGroupeSupp"
})
public class TypeHeureDTO {

    @XmlElement(required = true)
    protected String codTypHeure;
    @XmlElement(nillable = true)
    protected String nbrHeureElp;
    @XmlElement(nillable = true)
    protected String normeGroupe;
    @XmlElement(nillable = true)
    protected String nbrMinEtuOuvertureGroupeSupp;

    /**
     * Obtient la valeur de la propriété codTypHeure.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodTypHeure() {
        return codTypHeure;
    }

    /**
     * Définit la valeur de la propriété codTypHeure.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodTypHeure(String value) {
        this.codTypHeure = value;
    }

    /**
     * Obtient la valeur de la propriété nbrHeureElp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNbrHeureElp() {
        return nbrHeureElp;
    }

    /**
     * Définit la valeur de la propriété nbrHeureElp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNbrHeureElp(String value) {
        this.nbrHeureElp = value;
    }

    /**
     * Obtient la valeur de la propriété normeGroupe.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNormeGroupe() {
        return normeGroupe;
    }

    /**
     * Définit la valeur de la propriété normeGroupe.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNormeGroupe(String value) {
        this.normeGroupe = value;
    }

    /**
     * Obtient la valeur de la propriété nbrMinEtuOuvertureGroupeSupp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNbrMinEtuOuvertureGroupeSupp() {
        return nbrMinEtuOuvertureGroupeSupp;
    }

    /**
     * Définit la valeur de la propriété nbrMinEtuOuvertureGroupeSupp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNbrMinEtuOuvertureGroupeSupp(String value) {
        this.nbrMinEtuOuvertureGroupeSupp = value;
    }

}
